==> opencart-1.3.0.tbz: www/opencart/admin/controller/module/manufacturer.php <==
<?php
class ControllerModuleManufacturer extends Controller {
	private $error = array(); 
	
	public function index() {   
		$this->load->language('module/manufacturer');

		$this->document->title = $this->language->get('heading_title');
		
		$this->load->model('setting/setting');
				
		if (($this->request->server['REQUEST_METHOD'] == 'POST') && ($this->validate())) {
			$this->model_setting_setting->editSetting('manufacturer', $this->request->post);		
					
			$this->session->data['success'] = $this->language->get('text_success');
						
			$this->redirect($this->url->https('extension/module'));
		}
				
		$this->data['heading_title'] = $this->language->get('heading_title');

		$this->data['text_enabled'] = $this->language->get('text_enabled');
		$this->data['text_disabled'] = $this->language->get('text_disabled');
		$this->data['text_left'] = $this->language->get('text_left');
		$this->data['text_right'] = $this->language->get('text_right');
		
		$this->data['entry_position'] = $this->language->get('entry_position');
		$this->data['entry_status'] = $this->language->get('entry_status');
		$this->data['entry_sort_order'] = $this->language->get('entry_sort_order');
		
		$this->data['button_save'] = $this->language->get('button_save');
		$this->data['button_cancel'] = $this->language->get('button_cancel');

		$this->data['tab_general'] = $this->language->get('tab_general');

		$this->data['error_warning'] = @$this->error['warning'];

  		$this->document->breadcrumbs = array();

   		$this->document->breadcrumbs[] = array(
       		'href'      => $this->url->https('common/home'),
       		'text'      => $this->language->get('text_home'),
      		'separator' => FALSE
   		);

   		$this->document->breadcrumbs[] = array(
       		'href'      => $this->url->https('extension/module'),
       		'text'      => $this->language->get('text_module'),
      		'separator' => ' :: '
   		);
		
   		$this->document->breadcrumbs[] = array(
       		'href'      => $this->url->https('module/manufacturer'),
       		'text'      => $this->language->get('heading_title'),
      		'separator' => ' :: '
   		);
		
		$this->data['action'] = $this->url->https('module/manufacturer');
		
		$this->data['cancel'] = $this->url->https('extension/module');

		if (isset($this->request->post['manufacturer_position'])) {
			$this->data['manufacturer_position'] = $this->request->post['manufacturer_position'];
		} else {
			$this->data['manufacturer_position'] = $this->config->get('manufacturer_position');
		}
		
		if (isset($this->request->post['manufacturer_status'])) {
			$this->data['manufacturer_status'] = $this->request->post['manufacturer_status'];
		} else {
			$this->data['manufacturer_status'] = $this->config->get('manufacturer_status');
		}
		
		if (isset($this->request->post['manufacturer_sort_order'])) {
			$this->data['manufacturer_sort_order'] = $this->request->post['manufacturer_sort_order'];
		} else {
			$this->data['manufacturer_sort_order'] = $this->config->get('manufacturer_sort_order');
		}				
		
		$this->id       = 'content';
		$this->template = 'module/manufacturer.tpl';
		$this->layout   = 'common/layout';
		
 		$this->render();
	}
	
	private function validate() {
		if (!$this->user->hasPermission('modify', 'module/manufacturer')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		
		if (!$this->error) {
			return TRUE;
		} else {
			return FALSE;
		}	
	}
}
?>

==> opencart-1.4.9.1.tbz: www/opencart/admin/controller/module/manufacturer.php <==
<?php
class ControllerModuleManufacturer extends Controller {
	private $error = array(); 
	
	public function index() {   
		$this->load->language('module/manufacturer');

		$this->document->title = $this->language->get('heading_title');
		
		$this->load->model('setting/setting');
				
		if (($this->request->server['REQUEST_METHOD'] == 'POST') && ($this->validate())) {
			$this->model_setting_setting->editSetting('manufacturer', $this->request->post);		
					
			$this->session->data['success'] = $this->language->get('text_success');
						
			$this->redirect(HTTPS_SERVER . 'index.php?route=extension/module&token=' . $this->session->data['token']);
		}
				
		$this->data['heading_title'] = $this->language->get('heading_title');

		$this->data['text_enabled'] = $this->language->get('text_enabled');
		$this->data['text_disabled'] = $this->language->get('text_disabled');
		$this->data['text_left'] = $this->language->get('text_left');
		$this->data['text_right'] = $this->language->get('text_right');
		
		$this->data['entry_position'] = $this->language->get('entry_position');
		$this->data['entry_status'] = $this->language->get('entry_status');
		$this->data['entry_sort_order'] = $this->language->get('entry_sort_order');
		
		$this->data['button_save'] = $this->language->get('button_save');
		$this->data['button_cancel'] = $this->language->get('button_cancel');

 		if (isset($this->error['warning'])) {
			$this->data['error_warning'] = $this->error['warning'];
		} else {
			$this->data['error_warning'] = '';
		}

  		$this->document->breadcrumbs = array();

   		$this->document->breadcrumbs[] = array(
       		'href'      => HTTPS_SERVER . 'index.php?route=common/home&token=' . $this->session->data['token'],
       		'text'      => $this->language->get('text_home'),
      		'separator' => FALSE
   		);

   		$this->document->breadcrumbs[] = array(
       		'href'      => HTTPS_SERVER . 'index.php?route=extension/module&token=' . $this->session->data['token'],
       		'text'      => $this->language->get('text_module'),
      		'separator' => ' :: '
   		);
		
   		$this->document->breadcrumbs[] = array(
       		'href'      => HTTPS_SERVER . 'index.php?route=module/manufacturer&token=' . $this->session->data['token'],
       		'text'      => $this->language->get('heading_title'),
      		'separator' => ' :: '
   		);
		
		$this->data['action'] = HTTPS_SERVER . 'index.php?route=module/manufacturer&token=' . $this->session->data['token'];
		
		$this->data['cancel'] = HTTPS_SERVER . 'index.php?route=extension/module&token=' . $this->session->data['token'];

		if (isset($this->request->post['manufacturer_position'])) {
			$this->data['manufacturer_position'] = $this->request->post['manufacturer_position'];
		} else {
			$this->data['manufacturer_position'] = $this->config->get('manufacturer_position');
		}
		
		if (isset($this->request->post['manufacturer_status'])) {
			$this->data['manufacturer_status'] = $this->request->post['manufacturer_status'];
		} else {
			$this->data['manufacturer_status'] = $this->config->get('manufacturer_status');
		}
		
		if (isset($this->request->post['manufacturer_sort_order'])) {
			$this->data['manufacturer_sort_order'] = $this->request->post['manufacturer_sort_order'];
		} else {
			$this->data['manufacturer_sort_order'] = $this->config->get('manufacturer_sort_order');
		}				
		
		$this->template = 'module/manufacturer.tpl';
		$this->children = array(
			'common/header',	
			'common/footer'	
		);
		
		$this->response->setOutput($this->render(TRUE), $this->config->get('config_compression'));
	}
	
	private function validate() {
		if (!$this->user->hasPermission('modify', 'module/manufacturer')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		
		if (!$this->error) {
			return TRUE;
		} else {
			return FALSE;
		}	
	}
}
?>
